<?php

namespace Drupal\ai_comment_moderation\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Defines a form that configures the OpenAI API key setting.
 */
class AiModerationSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ai_comment_moderation.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ai_moderation_settings_form';
  }

  /**
   * Builds the settings form for entering OpenAI API key.
   *
   * @param array $form
   *   The form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The completed form array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('ai_comment_moderation.settings');

    $form['openai_api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('OpenAI API Key'),
      '#default_value' => $config->get('openai_api_key'),
      '#description' => $this->t('Enter your OpenAI API key.'),
      '#required' => TRUE,
      '#maxlength' => 256,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Handles form submission and saves the configuration.
   *
   * @param array $form
   *   The submitted form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The form state after submission.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('ai_comment_moderation.settings')
      ->set('openai_api_key', $form_state->getValue('openai_api_key'))
      ->save();

    $this->messenger()->addStatus($this->t('OpenAI API Key saved successfully.'));

    parent::submitForm($form, $form_state);
  }

}
